@@ -2,7 +2,6 @@ import esphome.codegen as cg
 import esphome.config_validation as cv
 from esphome.components import i2c, sensor, text_sensor
 from esphome.const import (
-    CONF_ICON,
     CONF_ID,
     ICON_RADIATOR,
     ICON_RESTART,
@@ -47,11 +46,8 @@ CONFIG_SCHEMA = (
                 device_class=DEVICE_CLASS_VOLATILE_ORGANIC_COMPOUNDS,
                 state_class=STATE_CLASS_MEASUREMENT,
             ),
-            cv.Optional(CONF_VERSION): text_sensor.TEXT_SENSOR_SCHEMA.extend(
-                {
-                    cv.GenerateID(): cv.declare_id(text_sensor.TextSensor),
-                    cv.Optional(CONF_ICON, default=ICON_RESTART): cv.icon,
-                }
+            cv.Optional(CONF_VERSION): text_sensor.text_sensor_schema(
+                icon=ICON_RESTART
             ),
             cv.Optional(CONF_BASELINE): cv.hex_uint16_t,
             cv.Optional(CONF_TEMPERATURE): cv.use_id(sensor.Sensor),
@@ -74,8 +70,7 @@ async def to_code(config):
     cg.add(var.set_tvoc(sens))
 
     if CONF_VERSION in config:
-        sens = cg.new_Pvariable(config[CONF_VERSION][CONF_ID])
-        await text_sensor.register_text_sensor(sens, config[CONF_VERSION])
+        sens = await text_sensor.new_text_sensor(config[CONF_VERSION])
         cg.add(var.set_version(sens))
 
     if CONF_BASELINE in config:
