@@ -68,6 +68,12 @@ void LightState::setup() {
         recovered.state = !recovered.state;
       }
       break;
+    case LIGHT_RESTORE_AND_OFF:
+    case LIGHT_RESTORE_AND_ON:
+      this->rtc_ = global_preferences->make_preference<LightStateRTCState>(this->get_object_id_hash());
+      this->rtc_.load(&recovered);
+      recovered.state = (this->restore_mode_ == LIGHT_RESTORE_AND_ON);
+      break;
     case LIGHT_ALWAYS_OFF:
       recovered.state = false;
       break;
