@@ -2,14 +2,14 @@ import esphome.codegen as cg
 import esphome.config_validation as cv
 from esphome.components import i2c, sensor
 from esphome.const import (
-    CONF_ID,
     CONF_UPDATE_INTERVAL,
     DEVICE_CLASS_TEMPERATURE,
-    ICON_EMPTY,
+    STATE_CLASS_MEASUREMENT,
     UNIT_CELSIUS,
 )
 
 DEPENDENCIES = ["i2c"]
+CODEOWNERS = ["@Azimath"]
 
 tmp117_ns = cg.esphome_ns.namespace("tmp117")
 TMP117Component = tmp117_ns.class_(
@@ -17,11 +17,12 @@ TMP117Component = tmp117_ns.class_(
 )
 
 CONFIG_SCHEMA = cv.All(
-    sensor.sensor_schema(UNIT_CELSIUS, ICON_EMPTY, 1, DEVICE_CLASS_TEMPERATURE)
-    .extend(
-        {
-            cv.GenerateID(): cv.declare_id(TMP117Component),
-        }
+    sensor.sensor_schema(
+        TMP117Component,
+        unit_of_measurement=UNIT_CELSIUS,
+        accuracy_decimals=1,
+        device_class=DEVICE_CLASS_TEMPERATURE,
+        state_class=STATE_CLASS_MEASUREMENT,
     )
     .extend(cv.polling_component_schema("60s"))
     .extend(i2c.i2c_device_schema(0x48))
@@ -70,11 +71,10 @@ def determine_config_register(polling_period):
     return 0x0000
 
 
-def to_code(config):
-    var = cg.new_Pvariable(config[CONF_ID])
-    yield cg.register_component(var, config)
-    yield i2c.register_i2c_device(var, config)
-    yield sensor.register_sensor(var, config)
+async def to_code(config):
+    var = await sensor.new_sensor(config)
+    await cg.register_component(var, config)
+    await i2c.register_i2c_device(var, config)
 
     update_period = config[CONF_UPDATE_INTERVAL].total_seconds
     cg.add(var.set_config(determine_config_register(update_period)))
