@@ -1,6 +1,6 @@
 """Constants used by esphome."""
 
-__version__ = "2022.2.3"
+__version__ = "2022.3.1"
 
 ALLOWED_NAME_CHARS = "abcdefghijklmnopqrstuvwxyz0123456789-_"
 
@@ -89,6 +89,7 @@ CONF_CHANGE_MODE_EVERY = "change_mode_every"
 CONF_CHANNEL = "channel"
 CONF_CHANNELS = "channels"
 CONF_CHIPSET = "chipset"
+CONF_CLEAR_IMPEDANCE = "clear_impedance"
 CONF_CLIENT_ID = "client_id"
 CONF_CLK_PIN = "clk_pin"
 CONF_CLOCK_PIN = "clock_pin"
@@ -306,6 +307,7 @@ CONF_INTENSITY = "intensity"
 CONF_INTERLOCK = "interlock"
 CONF_INTERNAL = "internal"
 CONF_INTERNAL_FILTER = "internal_filter"
+CONF_INTERNAL_FILTER_MODE = "internal_filter_mode"
 CONF_INTERRUPT = "interrupt"
 CONF_INTERVAL = "interval"
 CONF_INVALID_COOLDOWN = "invalid_cooldown"
@@ -344,6 +346,7 @@ CONF_LOOP_TIME = "loop_time"
 CONF_LOW = "low"
 CONF_LOW_VOLTAGE_REFERENCE = "low_voltage_reference"
 CONF_MAC_ADDRESS = "mac_address"
+CONF_MAGNITUDE = "magnitude"
 CONF_MAINS_FILTER = "mains_filter"
 CONF_MAKE_ID = "make_id"
 CONF_MANUAL_IP = "manual_ip"
@@ -619,6 +622,7 @@ CONF_SLEEP_PIN = "sleep_pin"
 CONF_SLEEP_WHEN_DONE = "sleep_when_done"
 CONF_SONY = "sony"
 CONF_SOURCE = "source"
+CONF_SOURCE_ID = "source_id"
 CONF_SPEED = "speed"
 CONF_SPEED_COMMAND_TOPIC = "speed_command_topic"
 CONF_SPEED_COUNT = "speed_count"
@@ -735,6 +739,7 @@ CONF_VOLTAGE_DIVIDER = "voltage_divider"
 CONF_WAIT_TIME = "wait_time"
 CONF_WAIT_UNTIL = "wait_until"
 CONF_WAKEUP_PIN = "wakeup_pin"
+CONF_WAND_ID = "wand_id"
 CONF_WARM_WHITE = "warm_white"
 CONF_WARM_WHITE_COLOR_TEMPERATURE = "warm_white_color_temperature"
 CONF_WATCHDOG_THRESHOLD = "watchdog_threshold"
